@@ -342,6 +342,7 @@
 #define CURLM_UNKNOWN_OPTION_FIRST 0x070f04 /* Added in 7.15.4 */
 #define CURLM_WAKEUP_FAILURE_FIRST 0x074400 /* Added in 7.68.0 */
 #define CURLOPT_FIRST 0x074500 /* Added in 7.69.0 */
+#define CURLOPTTYPE_BLOB_FIRST 0x074700 /* Added in 7.71.0 */
 #define CURLOPTTYPE_FUNCTIONPOINT_FIRST 0x070100 /* Added in 7.1 */
 #define CURLOPTTYPE_LONG_FIRST 0x070100 /* Added in 7.1 */
 #define CURLOPTTYPE_OBJECTPOINT_FIRST 0x070100 /* Added in 7.1 */
@@ -457,6 +458,7 @@
 #define CURLOPT_IOCTLFUNCTION_FIRST 0x070c03 /* Added in 7.12.3 */
 #define CURLOPT_IPRESOLVE_FIRST 0x070a08 /* Added in 7.10.8 */
 #define CURLOPT_ISSUERCERT_FIRST 0x071300 /* Added in 7.19.0 */
+#define CURLOPT_ISSUERCERT_BLOB_FIRST 0x074700 /* Added in 7.71.0 */
 #define CURLOPT_KEEP_SENDING_ON_ERROR_FIRST 0x073300 /* Added in 7.51.0 */
 #define CURLOPT_KEYPASSWD_FIRST 0x071100 /* Added in 7.17.0 */
 #define CURLOPT_KRB4LEVEL_FIRST 0x070300 /* Added in 7.3 */
@@ -517,6 +519,8 @@
 #define CURLOPT_PROGRESSFUNCTION_FIRST 0x070100 /* Added in 7.1 */
 #define CURLOPT_PROTOCOLS_FIRST 0x071304 /* Added in 7.19.4 */
 #define CURLOPT_PROXY_FIRST 0x070100 /* Added in 7.1 */
+#define CURLOPT_PROXY_ISSUERCERT_FIRST 0x074700 /* Added in 7.71.0 */
+#define CURLOPT_PROXY_ISSUERCERT_BLOB_FIRST 0x074700 /* Added in 7.71.0 */
 #define CURLOPT_PROXYAUTH_FIRST 0x070a07 /* Added in 7.10.7 */
 #define CURLOPT_PROXYHEADER_FIRST 0x072500 /* Added in 7.37.0 */
 #define CURLOPT_PROXYPASSWORD_FIRST 0x071301 /* Added in 7.19.1 */
@@ -531,8 +535,10 @@
 #define CURLOPT_PROXY_PINNEDPUBLICKEY_FIRST 0x073400 /* Added in 7.52.0 */
 #define CURLOPT_PROXY_SERVICE_NAME_FIRST 0x072b00 /* Added in 7.43.0 */
 #define CURLOPT_PROXY_SSLCERT_FIRST 0x073400 /* Added in 7.52.0 */
+#define CURLOPT_PROXY_SSLCERT_BLOB_FIRST 0x074700 /* Added in 7.71.0 */
 #define CURLOPT_PROXY_SSLCERTTYPE_FIRST 0x073400 /* Added in 7.52.0 */
 #define CURLOPT_PROXY_SSLKEY_FIRST 0x073400 /* Added in 7.52.0 */
+#define CURLOPT_PROXY_SSLKEY_BLOB_FIRST 0x074700 /* Added in 7.71.0 */
 #define CURLOPT_PROXY_SSLKEYTYPE_FIRST 0x073400 /* Added in 7.52.0 */
 #define CURLOPT_PROXY_SSLVERSION_FIRST 0x073400 /* Added in 7.52.0 */
 #define CURLOPT_PROXY_SSL_CIPHER_LIST_FIRST 0x073400 /* Added in 7.52.0 */
@@ -602,11 +608,13 @@
 #define CURLOPT_SSH_PRIVATE_KEYFILE_FIRST 0x071001 /* Added in 7.16.1 */
 #define CURLOPT_SSH_PUBLIC_KEYFILE_FIRST 0x071001 /* Added in 7.16.1 */
 #define CURLOPT_SSLCERT_FIRST 0x070100 /* Added in 7.1 */
+#define CURLOPT_SSLCERT_BLOB_FIRST 0x074700 /* Added in 7.71.0 */
 #define CURLOPT_SSLCERTPASSWD_FIRST 0x070101 /* Added in 7.1.1 */
 #define CURLOPT_SSLCERTTYPE_FIRST 0x070903 /* Added in 7.9.3 */
 #define CURLOPT_SSLENGINE_FIRST 0x070903 /* Added in 7.9.3 */
 #define CURLOPT_SSLENGINE_DEFAULT_FIRST 0x070903 /* Added in 7.9.3 */
 #define CURLOPT_SSLKEY_FIRST 0x070903 /* Added in 7.9.3 */
+#define CURLOPT_SSLKEY_BLOB_FIRST 0x074700 /* Added in 7.71.0 */
 #define CURLOPT_SSLKEYPASSWD_FIRST 0x070903 /* Added in 7.9.3 */
 #define CURLOPT_SSLKEYTYPE_FIRST 0x070903 /* Added in 7.9.3 */
 #define CURLOPT_SSLVERSION_FIRST 0x070100 /* Added in 7.1 */
@@ -755,6 +763,7 @@
 #define CURLSSLBACKEND_SECURETRANSPORT_FIRST 0x074001 /* Added in 7.64.1 */
 #define CURLSSLBACKEND_WOLFSSL_FIRST 0x073100 /* Added in 7.49.0 */
 #define CURLSSLOPT_ALLOW_BEAST_FIRST 0x071900 /* Added in 7.25.0 */
+#define CURLSSLOPT_NATIVE_CA_FIRST 0x074700 /* Added in 7.71.0 */
 #define CURLSSLOPT_NO_PARTIALCHAIN_FIRST 0x074400 /* Added in 7.68.0 */
 #define CURLSSLOPT_NO_REVOKE_FIRST 0x072c00 /* Added in 7.44.0 */
 #define CURLSSLSET_NO_BACKENDS_FIRST 0x073800 /* Added in 7.56.0 */
